from PyObjCTools.TestSupport import TestCase

import VideoSubscriberAccount


class TestCallableMetadata(TestCase):
    def test_callable_metadata_is_sane(self):
        self.assertCallableMetadataIsSane(VideoSubscriberAccount)



from PyObjCTools.TestSupport import TestCase
import VideoSubscriberAccount


class TestVSSubscription(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(VideoSubscriberAccount.VSSubscriptionAccessLevel)

    def testConstants(self):
        self.assertEqual(VideoSubscriberAccount.VSSubscriptionAccessLevelUnknown, 0)
        self.assertEqual(
            VideoSubscriberAccount.VSSubscriptionAccessLevelFreeWithAccount, 1
        )
        self.assertEqual(VideoSubscriberAccount.VSSubscriptionAccessLevelPaid, 2)

    def testClasses(self):
        VideoSubscriberAccount.VSSubscription



# This file is generated by objective.metadata
#
# Last update: Sat May 18 09:38:18 2024
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$VSAccountProviderAuthenticationSchemeAPI$VSAccountProviderAuthenticationSchemeSAML$VSCheckAccessOptionPrompt$VSErrorDomain$VSErrorInfoKeyAccountProviderResponse$VSErrorInfoKeySAMLResponse$VSErrorInfoKeySAMLResponseStatus$VSErrorInfoKeyUnsupportedProviderIdentifier$VSOpenTVProviderSettingsURLString$"""
enums = """$VSAccountAccessStatusDenied@2$VSAccountAccessStatusGranted@3$VSAccountAccessStatusNotDetermined@0$VSAccountAccessStatusRestricted@1$VSErrorCodeAccessNotGranted@0$VSErrorCodeInvalidVerificationToken@5$VSErrorCodeProviderRejected@4$VSErrorCodeRejected@6$VSErrorCodeServiceTemporarilyUnavailable@3$VSErrorCodeUnsupported@7$VSErrorCodeUnsupportedProvider@1$VSErrorCodeUserCancelled@2$VSOriginatingDeviceCategoryMobile@0$VSOriginatingDeviceCategoryOther@1$VSSubscriptionAccessLevelFreeWithAccount@1$VSSubscriptionAccessLevelPaid@2$VSSubscriptionAccessLevelUnknown@0$VSUserAccountQueryAllDevices@1$VSUserAccountQueryNone@0$VSUserAccountTypeFree@0$VSUserAccountTypePaid@1$"""
misc.update(
    {
        "VSOriginatingDeviceCategory": NewType("VSOriginatingDeviceCategory", int),
        "VSSubscriptionAccessLevel": NewType("VSSubscriptionAccessLevel", int),
        "VSUserAccountType": NewType("VSUserAccountType", int),
        "VSAccountAccessStatus": NewType("VSAccountAccessStatus", int),
        "VSErrorCode": NewType("VSErrorCode", int),
        "VSUserAccountQueryOptions": NewType("VSUserAccountQueryOptions", int),
    }
)
misc.update({})
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"accountManager:dismissViewController:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"accountManager:presentViewController:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"accountManager:shouldAuthenticateAccountProviderWithIdentifier:",
        {
            "required": False,
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"VSAccountManager",
        b"checkAccessStatusWithOptions:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"q"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VSAccountManager",
        b"enqueueAccountMetadataRequest:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"VSAccountMetadataRequest", b"forceAuthentication", {"retval": {"type": b"Z"}})
    r(
        b"VSAccountMetadataRequest",
        b"includeAccountProviderIdentifier",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"VSAccountMetadataRequest",
        b"includeAuthenticationExpirationDate",
        {"retval": {"type": b"Z"}},
    )
    r(b"VSAccountMetadataRequest", b"isInterruptionAllowed", {"retval": {"type": b"Z"}})
    r(
        b"VSAccountMetadataRequest",
        b"setForceAuthentication:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"VSAccountMetadataRequest",
        b"setIncludeAccountProviderIdentifier:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"VSAccountMetadataRequest",
        b"setIncludeAuthenticationExpirationDate:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"VSAccountMetadataRequest",
        b"setInterruptionAllowed:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"VSUserAccount", b"isDeleted", {"retval": {"type": b"Z"}})
    r(b"VSUserAccount", b"isFromCurrentDevice", {"retval": {"type": b"Z"}})
    r(b"VSUserAccount", b"isSignedOut", {"retval": {"type": b"Z"}})
    r(b"VSUserAccount", b"requiresSystemTrust", {"retval": {"type": b"Z"}})
    r(b"VSUserAccount", b"setDeleted:", {"arguments": {2: {"type": b"Z"}}})
    r(b"VSUserAccount", b"setRequiresSystemTrust:", {"arguments": {2: {"type": b"Z"}}})
    r(b"VSUserAccount", b"setSignedOut:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"VSUserAccountManager",
        b"queryUserAccountsWithOptions:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VSUserAccountManager",
        b"updateUserAccount:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
finally:
    objc._updatingMetadata(False)

objc.registerNewKeywordsFromSelector(
    "VSAccountApplicationProvider", b"initWithLocalizedDisplayName:identifier:"
)
objc.registerNewKeywordsFromSelector(
    "VSAppleSubscription", b"initWithCustomerID:productCodes:"
)
objc.registerNewKeywordsFromSelector("VSUserAccount", b"initWithAccountType:updateURL:")
expressions = {}

# END OF FILE



"""
Python mapping for the VideoSubscriberAccount framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""


def _setup():
    import sys

    import Foundation
    import objc
    from . import _metadata

    dir_func, getattr_func = objc.createFrameworkDirAndGetattr(
        name="VideoSubscriberAccount",
        frameworkIdentifier="com.apple.VideoSubscriberAccount.VideoSubscriberAccountFramework",
        frameworkPath=objc.pathForFramework(
            "/System/Library/Frameworks/VideoSubscriberAccount.framework"
        ),
        globals_dict=globals(),
        inline_list=None,
        parents=(Foundation,),
        metadict=_metadata.__dict__,
    )

    globals()["__dir__"] = dir_func
    globals()["__getattr__"] = getattr_func

    for cls, sel in (
        ("VSAccountApplicationProvider", b"init"),
        ("VSAccountApplicationProvider", b"new"),
        ("VSAppleSubscription", b"init"),
        ("VSAppleSubscription", b"new"),
        ("VSAccountManagerResult", b"init"),
        ("VSAccountManagerResult", b"new"),
        ("VSUserAccount", b"init"),
        ("VSUserAccount", b"new"),
    ):
        objc.registerUnavailableMethod(cls, sel)

    del sys.modules["VideoSubscriberAccount._metadata"]


globals().pop("_setup")()



from PyObjCTools.TestSupport import TestCase
import VideoSubscriberAccount


class TestVideoSubscriberAccountErrors(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(VideoSubscriberAccount.VSErrorCode)

    def testConstants(self):
        self.assertIsInstance(VideoSubscriberAccount.VSErrorDomain, str)
        self.assertIsInstance(VideoSubscriberAccount.VSErrorInfoKeySAMLResponse, str)
        self.assertIsInstance(
            VideoSubscriberAccount.VSErrorInfoKeySAMLResponseStatus, str
        )
        self.assertIsInstance(
            VideoSubscriberAccount.VSErrorInfoKeyAccountProviderResponse, str
        )
        self.assertIsInstance(
            VideoSubscriberAccount.VSErrorInfoKeyUnsupportedProviderIdentifier, str
        )

        self.assertEqual(VideoSubscriberAccount.VSErrorCodeAccessNotGranted, 0)
        self.assertEqual(VideoSubscriberAccount.VSErrorCodeUnsupportedProvider, 1)
        self.assertEqual(VideoSubscriberAccount.VSErrorCodeUserCancelled, 2)
        self.assertEqual(
            VideoSubscriberAccount.VSErrorCodeServiceTemporarilyUnavailable, 3
        )
        self.assertEqual(VideoSubscriberAccount.VSErrorCodeProviderRejected, 4)
        self.assertEqual(VideoSubscriberAccount.VSErrorCodeInvalidVerificationToken, 5)
        self.assertEqual(VideoSubscriberAccount.VSErrorCodeRejected, 6)
        self.assertEqual(VideoSubscriberAccount.VSErrorCodeUnsupported, 7)
